package org.sonatype.ahc.certs;

/*
 * Copyright (c) 2010 Sonatype, Inc. All rights reserved.
 *
 * This program is licensed to you under the Apache License Version 2.0, 
 * and you may not use this file except in compliance with the Apache License Version 2.0. 
 * You may obtain a copy of the Apache License Version 2.0 at http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing, 
 * software distributed under the Apache License Version 2.0 is distributed on an 
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the Apache License Version 2.0 for the specific language governing permissions and limitations there under.
 */

import java.io.File;
import java.io.FileNotFoundException;
import java.io.RandomAccessFile;

import javax.net.ssl.SSLException;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.ning.http.client.Response;
import com.ning.http.client.extra.ResumableRandomAccessFileHandler;
import com.ning.http.client.resumable.PropertiesBasedResumableProcessor;
import com.ning.http.client.resumable.ResumableAsyncHandler;

/**
 * @author Benjamin Hanzelmann
 */
class CertAwareAsyncHandler
    // extends AsyncCompletionHandlerBase
    extends ResumableAsyncHandler<Response>
{

    public CertAwareAsyncHandler()
    {
        super( true );
    }

    public CertAwareAsyncHandler( File target )
        throws FileNotFoundException
    {
        this( new RandomAccessFile( target, "rw" ) );
    }

    public CertAwareAsyncHandler( RandomAccessFile target )
    {
        super( new PropertiesBasedResumableProcessor() );
        setResumableListener( new ResumableRandomAccessFileHandler( target ) );
    }

    @SuppressWarnings( "unused" )
    private final Logger logger = LoggerFactory.getLogger( getClass() );

    @Override
    public void onThrowable( Throwable t )
    {
        if ( t.getCause() instanceof SSLException || t instanceof SSLException )
        {
            // TODO custom error handling?
        }
        else
        {
            super.onThrowable( t );
        }
    }

}
