package org.sonatype.ahc.certs;

/*
 * Copyright (c) 2010 Sonatype, Inc. All rights reserved.
 *
 * This program is licensed to you under the Apache License Version 2.0, 
 * and you may not use this file except in compliance with the Apache License Version 2.0. 
 * You may obtain a copy of the Apache License Version 2.0 at http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing, 
 * software distributed under the Apache License Version 2.0 is distributed on an 
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the Apache License Version 2.0 for the specific language governing permissions and limitations there under.
 */

import java.util.concurrent.ExecutionException;
import java.util.concurrent.Future;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.TimeoutException;

import com.ning.http.client.AsyncHttpClient;

/**
 * Wrapper around a Future object as returned by AHC that closes the client when it is not needed anymore.
 * 
 * @author Benjamin Hanzelmann
 */
@SuppressWarnings( "rawtypes" )
class ClosingFuture
    implements Future
{

    private final Future future;

    private AsyncHttpClient client;

    public ClosingFuture( AsyncHttpClient reference, Future future )
    {
        this.future = future;
        this.client = reference;
    }

    public boolean cancel( boolean mayInterruptIfRunning )
    {
        try
        {
            return future.cancel( mayInterruptIfRunning );
        }
        finally
        {
            client.close();
            client = null;
        }
    }

    public boolean isCancelled()
    {
        return future.isCancelled();
    }

    public boolean isDone()
    {
        return future.isDone();
    }

    public Object get()
        throws InterruptedException, ExecutionException
    {
        try
        {
            return future.get();
        }
        finally
        {
            client.close();
            client = null;
        }
    }

    public Object get( long timeout, TimeUnit unit )
        throws InterruptedException, ExecutionException, TimeoutException
    {
        try
        {
            return future.get( timeout, unit );
        }
        finally
        {
            client.close();
            client = null;
        }
    }
}