package org.sonatype.ahc.certs;

/*
 * Copyright (c) 2010 Sonatype, Inc. All rights reserved.
 *
 * This program is licensed to you under the Apache License Version 2.0, 
 * and you may not use this file except in compliance with the Apache License Version 2.0. 
 * You may obtain a copy of the Apache License Version 2.0 at http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing, 
 * software distributed under the Apache License Version 2.0 is distributed on an 
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the Apache License Version 2.0 for the specific language governing permissions and limitations there under.
 */

import java.security.PublicKey;
import java.security.cert.Certificate;
import java.security.cert.X509Certificate;

/**
 * @author Benjamin Hanzelmann
 */
public class DefaultCertificate
    extends AbstractEntry
    implements AHCCertificate
{

    private X509Certificate certificate;

    private PublicKey publicKey;

    public DefaultCertificate( String alias, Certificate certificate )
    {
        if ( !( certificate instanceof X509Certificate ) )
        {
            throw new IllegalArgumentException( "Unsupported Certificate Type (only X509): " + certificate.getClass() );
        }
        initialize( alias, (X509Certificate) certificate );
    }

    public DefaultCertificate( String alias, X509Certificate certificate )
    {
        initialize( alias, certificate );
    }

    public void initialize( String alias, X509Certificate certificate )
    {
        this.certificate = certificate;
        this.publicKey = certificate.getPublicKey();
        setType( Type.CERTIFICATE );
        setAlias( alias );
    }

    public X509Certificate getCertificate()
    {
        return certificate;
    }

    public PublicKey getPublicKey() {
        return publicKey;
    }

}
