package org.sonatype.ahc.certs;

/*
 * Copyright (c) 2010 Sonatype, Inc. All rights reserved.
 *
 * This program is licensed to you under the Apache License Version 2.0, 
 * and you may not use this file except in compliance with the Apache License Version 2.0. 
 * You may obtain a copy of the Apache License Version 2.0 at http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing, 
 * software distributed under the Apache License Version 2.0 is distributed on an 
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the Apache License Version 2.0 for the specific language governing permissions and limitations there under.
 */

import java.io.File;
import java.io.IOException;
import java.util.concurrent.Future;

import org.codehaus.plexus.component.annotations.Component;

import com.ning.http.client.AsyncHandler;
import com.ning.http.client.AsyncHttpClient;
import com.ning.http.client.AsyncHttpClientConfig;
import com.ning.http.client.RequestBuilder;
import com.ning.http.client.Response;


/**
 * @author Benjamin Hanzelmann
 */
@Component( role = Connector.class )
public class DefaultConnector
    implements Connector
{

    private Configurator configurator;

    public void setConfigurator( Configurator configurator )
    {
        this.configurator = configurator;
    }

    public DefaultConnector( Configurator configurator )
    {
        super();
        this.configurator = configurator;
    }

    public DefaultConnector()
    {
        super();
    }

    public Future<Response> execute( RequestBuilder request )
        throws IOException
    {
        return execute( configurator.build(), request );
    }

    public Future<Response> execute( RequestBuilder request, File target )
        throws IOException
    {
        return execute( configurator.build(), request, target );
    }

    public Future<Response> execute( AsyncHttpClientConfig config, RequestBuilder request )
        throws IOException
    {
        return execute( config, request, new CertAwareAsyncHandler() );
    }

    public Future<Response> execute( AsyncHttpClientConfig config, RequestBuilder request, File target )
        throws IOException
    {
        return execute( config, request, new CertAwareAsyncHandler( target ) );
    }

    public <T> Future<T> execute( AsyncHttpClientConfig config, RequestBuilder request,
                                  AsyncHandler<T> handler )
        throws IOException
    {
        if ( config == null )
        {
            throw new IllegalArgumentException( "config may not be null" );
        }

        if ( request == null )
        {
            throw new IllegalArgumentException( "request may not be null" );
        }

        if ( handler == null )
        {
            throw new IllegalArgumentException( "handler may not be null" );
        }

        AsyncHttpClient client = new AsyncHttpClient( config );

        @SuppressWarnings( "unchecked" )
        Future<T> future = new ClosingFuture( client, client.executeRequest( request.build(), handler ) );

        return future;
    }

}
