package org.sonatype.ahc.certs;

/*
 * Copyright (c) 2010 Sonatype, Inc. All rights reserved.
 *
 * This program is licensed to you under the Apache License Version 2.0, 
 * and you may not use this file except in compliance with the Apache License Version 2.0. 
 * You may obtain a copy of the Apache License Version 2.0 at http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing, 
 * software distributed under the Apache License Version 2.0 is distributed on an 
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the Apache License Version 2.0 for the specific language governing permissions and limitations there under.
 */

import java.util.Arrays;
import java.util.LinkedList;
import java.util.List;

/**
 * Aggregates multiple {@link AHCKeyManager}s and {@link AHCTrustManager}s to ease setting CertService-specific
 * properties.
 * 
 * @author Benjamin Hanzelmann
 */
class ManagerAggregate
{

    List<AHCKeyManager> keyManagers = new LinkedList<AHCKeyManager>();

    private final List<AHCTrustManager> trustManagers;

    public ManagerAggregate( AHCKeyManager[] keyManagers, AHCTrustManager[] trustManagers )
    {
        this( Arrays.asList( keyManagers ), Arrays.asList( trustManagers ) );
    }

    public ManagerAggregate( List<AHCKeyManager> keyManagers, List<AHCTrustManager> trustManagers )
    {
        super();
        this.keyManagers = keyManagers;
        this.trustManagers = trustManagers;
    }

    public List<AHCKeyManager> getManagers()
    {
        return keyManagers;
    }

    public void setAlias( String alias )
    {
        for ( AHCKeyManager manager : keyManagers )
        {
            manager.setAlias( alias );
        }
    }

    public void setTrustAll( boolean trustAll )
    {
        for ( AHCTrustManager manager : trustManagers )
        {
            manager.setTrustAll( trustAll );
        }
    }
}
