package org.sonatype.ahc.certs;

/*
 * Copyright (c) 2010 Sonatype, Inc. All rights reserved.
 *
 * This program is licensed to you under the Apache License Version 2.0, 
 * and you may not use this file except in compliance with the Apache License Version 2.0. 
 * You may obtain a copy of the Apache License Version 2.0 at http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing, 
 * software distributed under the Apache License Version 2.0 is distributed on an 
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the Apache License Version 2.0 for the specific language governing permissions and limitations there under.
 */

import com.ning.http.client.Request;
import com.ning.http.client.RequestBuilder;

/**
 * Helper class to prepare requests for the AHC.
 * 
 * @author Benjamin Hanzelmann
 */
public class Requests
{

    /**
     * Prepare an HTTP client GET request.
     * 
     * @param url A well formed URL.
     * @return {@link RequestBuilder}
     */
    public static RequestBuilder prepareGet( String url )
    {
        return requestBuilder( "GET", url );
    }

    private static RequestBuilder requestBuilder( String method, String url )
    {
        return new RequestBuilder( method ).setUrl( url );
    }

    /**
     * Prepare an HTTP client CONNECT request.
     * 
     * @param url A well formed URL.
     * @return {@link RequestBuilder}
     */
    public static RequestBuilder prepareConnect( String url )
    {
        return requestBuilder( "CONNECT", url );
    }

    /**
     * Prepare an HTTP client OPTIONS request.
     * 
     * @param url A well formed URL.
     * @return {@link RequestBuilder}
     */
    public static RequestBuilder prepareOptions( String url )
    {
        return requestBuilder( "OPTIONS", url );
    }

    /**
     * Prepare an HTTP client HEAD request.
     * 
     * @param url A well formed URL.
     * @return {@link RequestBuilder}
     */
    public static RequestBuilder prepareHead( String url )
    {
        return requestBuilder( "HEAD", url );
    }

    /**
     * Prepare an HTTP client POST request.
     * 
     * @param url A well formed URL.
     * @return {@link RequestBuilder}
     */
    public static RequestBuilder preparePost( String url )
    {
        return requestBuilder( "POST", url );
    }

    /**
     * Prepare an HTTP client PUT request.
     * 
     * @param url A well formed URL.
     * @return {@link RequestBuilder}
     */
    public static RequestBuilder preparePut( String url )
    {
        return requestBuilder( "PUT", url );
    }

    /**
     * Prepare an HTTP client DELETE request.
     * 
     * @param url A well formed URL.
     * @return {@link RequestBuilder}
     */
    public static RequestBuilder prepareDelete( String url )
    {
        return requestBuilder( "DELETE", url );
    }

    /**
     * Construct a {@link RequestBuilder} using a {@link Request}
     * 
     * @param request a {@link Request}
     * @return {@link RequestBuilder}
     */
    public static RequestBuilder prepareRequest( Request prototype )
    {
        return new RequestBuilder( prototype );
    }

}
