package org.sonatype.ahc.certs.manager;

import java.util.Collection;
import java.util.Collections;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;

import org.codehaus.plexus.component.annotations.Component;
import org.sonatype.ahc.certs.CertificateManager;
import org.sonatype.ahc.certs.Entry;

/*
 * Copyright (c) 2010 Sonatype, Inc. All rights reserved.
 *
 * This program is licensed to you under the Apache License Version 2.0, 
 * and you may not use this file except in compliance with the Apache License Version 2.0. 
 * You may obtain a copy of the Apache License Version 2.0 at http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing, 
 * software distributed under the Apache License Version 2.0 is distributed on an 
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the Apache License Version 2.0 for the specific language governing permissions and limitations there under.
 */


/**
 * @author Benjamin Hanzelmann
 */
@Component( role = CertificateManager.class )
public class DefaultCertificateManager
    implements CertificateManager
{

    final List<Entry> entries = Collections.synchronizedList( new LinkedList<Entry>() );

    public Collection<Entry> getEntries()
    {
        return Collections.unmodifiableCollection( entries );
    }

    public void add( Entry certificate )
    {
        entries.add( certificate );
    }

    public void remove( Entry certificate )
    {
        entries.remove( certificate );
    }

    public void remove( String alias )
    {
        Iterator<Entry> it = entries.iterator();
        while ( it.hasNext() )
        {
            if ( alias.equals( it.next().getAlias() ) )
            {
                it.remove();
                return;
            }
        }
    }

    public void add( Collection<Entry> certificates )
    {
        entries.addAll( certificates );
    }

    public void clear()
    {
        entries.clear();
    }

    public Entry getEntry( String alias )
    {
        for (Entry entry : entries) {
            if ( entry.getAlias().equals( alias ) )
            {
                return entry;
            }
        }

        return null;
    }

}
